%define anolis_release 3
Name:           python-poetry-core
Version:        1.7.0
Release:        %{anolis_release}%{?dist}
Summary:        Poetry PEP 517 Build Backend

# We bundle a lot of libraries with poetry, which itself is under MIT license.
# Here is the list of the libraries with corresponding licenses:

# attrs: MIT
# jsonschema: MIT
# lark: MIT
# packaging: ASL 2.0 or BSD
# pkgutil-resolve-name: MIT
# pyparsing: MIT
# pyrsistent: MIT
# tomlkit: MIT
# typing-extensions: Python

License:        MIT and (ASL 2.0 or BSD) and Python
URL:            https://github.com/python-poetry/poetry-core
Source0:        %{url}/archive/%{version}/poetry-core-%{version}.tar.gz

# This patch moves the vendored requires definition
# from vendors/pyproject.toml to pyproject.toml
# Intentionally contains the removed hunk to prevent patch aging

# poetry is broken with packaging 21+ (https://github.com/python-poetry/poetry/issues/4264).
# We are temporarily disabling this patch so installed poetry works again.
#Patch1:         poetry-core-1.0.2-devendor.patch

BuildArch:      noarch
BuildRequires:  python3-devel
BuildRequires:  pyproject-rpm-macros

# for tests (only specified via poetry poetry.dev-dependencies with pre-commit etc.)
BuildRequires:  python3-build
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-mock
BuildRequires:  python3-setuptools
BuildRequires:  python3-virtualenv
BuildRequires:  python3-tomli-w
BuildRequires:  gcc
BuildRequires:  git-core

Requires:       python3-tomli-w

%global _description %{expand:
A PEP 517 build backend implementation developed for Poetry.
This project is intended to be a light weight, fully compliant, self-contained
package allowing PEP 517 compatible build frontends to build Poetry managed
projects.}

%description %_description


%package -n python3-poetry-core
Summary:        %{summary}

# Previous versions of poetry included poetry-core in it
Conflicts:      python%{python3_version}dist(poetry) < 1.1
# The bundled versions are taken from src/poetry/core/_vendor/vendor.txt
Provides:       bundled(python3dist(attrs)) = 22.1
Provides:       bundled(python3dist(jsonschema)) = 4.10
Provides:       bundled(python3dist(lark)) = 1.1.2
Provides:       bundled(python3dist(packaging)) = 21.3
Provides:       bundled(python3dist(pkgutil-resolve-name)) = 1.3.10
Provides:       bundled(python3dist(pyparsing)) = 3.0.9
Provides:       bundled(python3dist(pyrsistent)) = 0.18.1
Provides:       bundled(python3dist(tomlkit)) = 0.11.4
Provides:       bundled(python3dist(typing-extensions)) = 4.3.0

%description -n python3-poetry-core %_description


%prep
%autosetup -p1 -n poetry-core-%{version}


%generate_buildrequires
%pyproject_buildrequires -r


%build
# we debundle the deps after we use the bundled deps in previous step to parse the deps 🤯
#rm -r poetry/core/_vendor

%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files poetry


%check
# don't use %%tox here because tox.ini runs "poetry install"
# TODO investigate failures in test_default_with_excluded_data, test_default_src_with_excluded_data
%pytest -k "not with_excluded_data and not robust_rmtree"


%files -n python3-poetry-core -f %{pyproject_files}
%doc README.md
%license LICENSE


%changelog
* Tue May 14 2024 Bo Ren <rb01097748@alibaba-inc.com> - 1.7.0-3
- update source

* Tue Mar 26 2024 Zhao Hang <wb-zh951434@alibaba-inc.com> - 1.7.0-2
- Rebuild with python3.11

* Tue Oct 31 2023 Zhongling He <zhonglingh@linux.alibaba.com> 1.7.0-1
- Upgrade to v1.7.0

* Mon Apr 10 2023 Funda Wang <fundawang@yeah.net> - 1.4.0-1
- Import package for anolis 23
